unit uUserSettings;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, Buttons;

type
  TfmUserSettings = class(TForm)
    cbAllowAnonymousLogin: TCheckBox;
    edAnonymousDir: TEdit;
    laAnonymousDir: TLabel;
    btBrowse: TButton;
    cbCheckPassForValidMail: TCheckBox;
    Label2: TLabel;
    lvUsers: TListView;
    sbtAdd: TSpeedButton;
    sbtEdit: TSpeedButton;
    btOk: TButton;
    btCancel: TButton;
    sbtDelete: TSpeedButton;
    procedure FormCreate(Sender: TObject);
    procedure sbtAddClick(Sender: TObject);
    procedure lvUsersSelectItem(Sender: TObject; Item: TListItem;
      Selected: Boolean);
    procedure sbtEditClick(Sender: TObject);
    procedure sbtDeleteClick(Sender: TObject);
    procedure btOkClick(Sender: TObject);
    procedure cbAllowAnonymousLoginClick(Sender: TObject);
  private
  public
  end;

var
  fmUserSettings: TfmUserSettings;

implementation

uses
  MD5, uAddEditUser;

{$R *.dfm}

procedure AddDisabledBMP(SB: array of TObject);
var
  BM, SBM: TBitmap;
  w, x, y, NewColor, i: Integer;
  PixelColor: TColor;
begin
  BM:=TBitmap.Create;
  SBM:=TBitmap.Create;

  try
    for i:=0 to High(SB) do
      begin
        if (SB[i] is TSpeedButton) then
          BM.Assign((SB[i] as TSpeedButton).Glyph)
        else
          if (SB[i] is TBitBtn) then
            BM.Assign((SB[i] as TBitBtn).Glyph)
          else
            Exit;

        if not Assigned(BM) or (BM.Width <> BM.Height) then Exit;

        w:=BM.Width;
        SBM.Width:=w*2;
        SBM.Height:=w;
        SBM.Canvas.Draw(0, 0, BM);

          for x:=0 to w - 1 do
            for y:=0 to w - 1 do begin
              PixelColor:=ColorToRGB(BM.Canvas.Pixels[x, y]);
              NewColor:=Round((((PixelColor shr 16) + ((PixelColor shr 8) and $00FF) +
                         (PixelColor and $0000FF)) div 3)) div 2 + 96;
              BM.Canvas.Pixels[x, y]:=RGB(NewColor, NewColor, NewColor);
            end;

        SBM.Canvas.Draw(w, 0, BM);

        if (SB[i] is TSpeedButton) then
          with (SB[i] as TSpeedButton) do
            begin
              Glyph.Assign(SBM);
              NumGlyphs:=2;
            end
        else
          with (SB[i] as TBitBtn) do
            begin
              Glyph.Assign(SBM);
              NumGlyphs:=2;
            end;

        BM:=TBitmap.Create;
        SBM:=TBitmap.Create;
      end;
  finally
    BM.Free;
    SBM.Free;
  end;
end;

procedure TfmUserSettings.FormCreate(Sender: TObject);
begin
  AddDisabledBMP([sbtEdit, sbtDelete]);
end;

procedure TfmUserSettings.sbtAddClick(Sender: TObject);
begin
  fmAddEditUser:=TfmAddEditUser.Create(Self);
  try
    fmAddEditUser.Caption:=' ';
    fmAddEditUser.ShowModal;
    if fmAddEditUser.ModalResult = mrOk then
      with lvUsers.Items.Add do
        begin
          Caption:=fmAddEditUser.edUserName.Text;
          SubItems.Add(IncludeTrailingPathDelimiter(fmAddEditUser.edWorkingDir.Text));
          SubItems.Add(MD5StrToString(fmAddEditUser.edPassword.Text));
        end;
    // it would be great to code checking for dups in user list
  finally
    fmAddEditUser.Free;
  end;
end;

procedure TfmUserSettings.lvUsersSelectItem(Sender: TObject;
  Item: TListItem; Selected: Boolean);
begin
  sbtEdit.Enabled:=lvUsers.Selected <> nil;
  sbtDelete.Enabled:=sbtEdit.Enabled;
end;

procedure TfmUserSettings.sbtEditClick(Sender: TObject);
begin
  fmAddEditUser:=TfmAddEditUser.Create(Self);
  try
    fmAddEditUser.Caption:='  ';
    fmAddEditUser.edUserName.Text:=lvUsers.Selected.Caption;
    fmAddEditUser.edWorkingDir.Text:=lvUsers.Selected.SubItems[0];
    fmAddEditUser.ShowModal;
    if fmAddEditUser.ModalResult = mrOk then
      with lvUsers.Selected do
        begin
          Caption:=fmAddEditUser.edUserName.Text;
          SubItems[0]:=fmAddEditUser.edWorkingDir.Text;
          SubItems[1]:=MD5StrToString(fmAddEditUser.edPassword.Text);
        end;
  finally
    fmAddEditUser.Free;
  end;
end;

procedure TfmUserSettings.sbtDeleteClick(Sender: TObject);
begin
  lvUsers.DeleteSelected;
end;

procedure TfmUserSettings.btOkClick(Sender: TObject);
begin
  if not DirectoryExists(edAnonymousDir.Text) then
    begin
      MessageBox(0, PChar(Format(' ''%s''  .'#13#10'       ""   .', [edAnonymousDir.Text])), '', MB_ICONERROR or MB_TASKMODAL or MB_OK);
      cbAllowAnonymousLogin.Checked:=true;
      edAnonymousDir.SetFocus;
      ModalResult:=mrNone;
    end;
end;

procedure TfmUserSettings.cbAllowAnonymousLoginClick(Sender: TObject);
var
  bEnable: boolean;
begin
  bEnable:=cbAllowAnonymousLogin.Checked;

  laAnonymousDir.Enabled:=bEnable;
  edAnonymousDir.Enabled:=bEnable;
  if bEnable then
    edAnonymousDir.Color:=clWindow
  else
    edAnonymousDir.Color:=clBtnFace;

  btBrowse.Enabled:=bEnable;
  cbCheckPassForValidMail.Enabled:=bEnable;
end;

end.
